elephant.test.test_spike_train_generation module — Elephant 0.5.0 documentation

# elephant.test.test_spike_train_generation module

Unit tests for the spike_train_generation module.

class `elephant.test.test_spike_train_generation.` `AnalogSignalPeakDetectionTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_peak_detection_threshold`()
  `test_peak_detection_time_stamps`()

class `elephant.test.test_spike_train_generation.` `AnalogSignalSpikeExtractionTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_spike_extraction_waveform`()

class `elephant.test.test_spike_train_generation.` `AnalogSignalThresholdDetectionTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_threshold_detection`()

class `elephant.test.test_spike_train_generation.` `HomogeneousGammaProcessTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_statistics`()

class `elephant.test.test_spike_train_generation.` `HomogeneousPoissonProcessTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_buffer_overrun`()
  `test_low_rates`()
  `test_statistics`()

class `elephant.test.test_spike_train_generation.` `InhomogeneousPoissonProcessTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_low_rates`()
  `test_negative_rates`()
  `test_statistics`()

class `elephant.test.test_spike_train_generation.` `cppTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_cpp_het`()
  `test_cpp_het_err`()
  `test_cpp_hom`()
  `test_cpp_hom_errors`()
  `test_cpp_jttered`()

`elephant.test.test_spike_train_generation.` `pdiff`(a, b)

  Difference between a and b as a fraction of a

  i.e. abs((a - b)/a)

class `elephant.test.test_spike_train_generation.` `singleinteractionprocess_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_sip`()
  `test_sip_error`()